:mod:`euphorie.client.profile`
==============================

.. automodule:: euphorie.client.profile

.. autofunction:: AddToTree

.. autofunction:: BuildSurveyTree

.. autofunction:: extractProfile

.. autofunction:: set_session_profile

.. autoclass:: Profile
   :members:

.. autoclass:: Update

